Please see [https://docs.mlcommons.org/cm4mlops/scripts/AI-ML-models/convert-ml-model-huggingface-to-onnx](https://docs.mlcommons.org/cm4mlops/scripts/AI-ML-models/convert-ml-model-huggingface-to-onnx) for the documentation of this CM script.
